@@ -150,13 +150,10 @@ contains_vars <- function(arg) {
 
 #' Turn a List of Expressions into a Character Vector
 #'
-#' @param expressions A `list` of expressions created using [`exprs()`]
-#'
-#' @param quosures *Deprecated*, please use `expressions` instead.
+#' @param expressions A `list` of expressions created using `exprs()`
 #'
 #' @return A character vector
 #'
-#'
 #' @export
 #'
 #' @keywords dev_utility
@@ -167,14 +164,7 @@ contains_vars <- function(arg) {
 #' library(rlang)
 #'
 #' vars2chr(exprs(USUBJID, AVAL))
-vars2chr <- function(expressions, quosures) {
-  if (!missing(quosures)) {
-    deprecate_stop(
-      "0.10.0",
-      "vars2chr(quosures = )",
-      "vars2chr(expressions = )"
-    )
-  }
+vars2chr <- function(expressions) {
   rlang::set_names(
     map_chr(expressions, as_string),
     names(expressions)
